==> nextcloud-app-mail-5.1.9-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uz.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Ish",
    "Personal" : "Personal",
    "Later" : "Keyinchalik",
    "Mail" : "Mail",
    "Save" : "Save",
    "Connect" : "Connect",
    "Name" : "Name",
    "Password" : "Password",
    "None" : "None",
    "Email address" : "E-pochta manzili",
    "Cancel" : "Cancel",
    "Accounts" : "Akkaunt",
    "General" : "General",
    "List" : "Ro`yxat",
    "Register" : "Roʻyxatdan oʻtish",
    "About" : "About",
    "Archive" : "Arxiv",
    "Delete" : "Delete",
    "Search" : "Search",
    "Send" : "Send",
    "Refresh" : "Refresh",
    "From" : "Dan",
    "To" : "Gacha",
    "Choose" : "Choose",
    "Choose a file to add as attachment" : "Ilova sifatida qo'shish uchun faylni tanlang",
    "Choose a file to share as a link" : "Havola sifatida almashish uchun faylni tanlang",
    "_{count} attachment_::_{count} attachments_" : ["{count} qo'shimchalar"],
    "Confirm" : "Confirm",
    "Favorite" : "Favorite",
    "More actions" : "Ko'proq harakatlar",
    "Back" : "Orqaga",
    "Create event" : "Tadbir yaratish",
    "All day" : "Butun kun",
    "Description" : "Tavsif",
    "Create" : "Yaratish",
    "Select" : "Select",
    "Comment" : "Izoh",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "More options" : "Boshqa variantlar",
    "Remove" : "Remove",
    "email" : "email",
    "Other" : "Boshqa",
    "Translate" : "Tarjima",
    "Move" : "Move",
    "Remove {email}" : " {email} ni o'chirish",
    "Folder name" : "Jild nomi",
    "Saving" : "Saving",
    "Delete folder" : "Jildni o'chirish",
    "Rename" : "Nomini o'zgartirish",
    "Subscribed" : "Obuna boʻlgan",
    "Reply" : "Javob bering",
    "Add" : "Add",
    "Close" : "Close",
    "Date" : "Sana",
    "Tags" : "Tags",
    "Last 7 days" : "Oxirgi 7 kun",
    "Custom" : "Boshqa",
    "Add tag" : "Teg qo'shing",
    "Not found" : "Topilmadi",
    "Untitled event" : "Nomsiz tadbir",
    "(organizer)" : "(tashkilotchi)",
    "Operator" : "Operator",
    "contains" : "o'z ichiga oladi",
    "Reset" : "Qayta tiklash",
    "Client ID" : "Mijoz identifikatori",
    "Port" : "Port",
    "Account connected" : "Akkaunt ulangan",
    "All" : "All",
    "Favorites" : "Favorites",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Continue to %s" : " %sni davom eting",
    "Actions" : "Faolliklar"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-5.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uz.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Ish",
    "Personal" : "Personal",
    "Later" : "Keyinchalik",
    "Mail" : "Mail",
    "Save" : "Saqlash",
    "Connect" : "Connect",
    "Name" : "Name",
    "Password" : "Password",
    "None" : "Yo'q",
    "Email address" : "E-pochta manzili",
    "Cancel" : "Bekor qilish",
    "Accounts" : "Akkaunt",
    "General" : "Umumiy",
    "List" : "Ro`yxat",
    "Register" : "Roʻyxatdan oʻtish",
    "About" : "About",
    "Archive" : "Arxiv",
    "Delete" : "O'chirish",
    "Search" : "Qidirish",
    "Send" : "Send",
    "Refresh" : "Refresh",
    "Ok" : "Yaxshi",
    "From" : "Dan",
    "To" : "Gacha",
    "Choose" : "Choose",
    "Choose a file to add as attachment" : "Ilova sifatida qo'shish uchun faylni tanlang",
    "Choose a file to share as a link" : "Havola sifatida almashish uchun faylni tanlang",
    "_{count} attachment_::_{count} attachments_" : ["{count} qo'shimchalar"],
    "Confirm" : "Confirm",
    "Favorite" : "Favorite",
    "More actions" : "Ko'proq harakatlar",
    "Back" : "Orqaga",
    "Create event" : "Tadbir yaratish",
    "All day" : "Butun kun",
    "Description" : "Tavsif",
    "Create" : "Yaratish",
    "Select" : "Select",
    "Comment" : "Izoh",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "More options" : "Boshqa variantlar",
    "Remove" : "O'chirish",
    "email" : "email",
    "Today" : "Bugun",
    "Yesterday" : "Kecha",
    "Last week" : "O`tgan yil",
    "Last month" : "Oxirgi oy",
    "Other" : "Boshqa",
    "Translate" : "Tarjima",
    "Move" : "Move",
    "Remove {email}" : " {email} ni o'chirish",
    "Folder name" : "Jild nomi",
    "Saving" : "Saving",
    "Delete folder" : "Jildni o'chirish",
    "Rename" : "Nomini o'zgartirish",
    "Subscribed" : "Obuna boʻlgan",
    "Reply" : "Javob bering",
    "Add" : "Add",
    "Close" : "Yopish",
    "Date" : "Sana",
    "Tags" : "Tags",
    "Last 7 days" : "Oxirgi 7 kun",
    "Custom" : "Boshqa",
    "Add tag" : "Teg qo'shing",
    "Not found" : "Topilmadi",
    "Untitled event" : "Nomsiz tadbir",
    "(organizer)" : "(tashkilotchi)",
    "Operator" : "Operator",
    "contains" : "o'z ichiga oladi",
    "Reset" : "Qayta tiklash",
    "Client ID" : "Mijoz identifikatori",
    "Port" : "Port",
    "Shared" : "Ulashilgan",
    "Account connected" : "Akkaunt ulangan",
    "All" : "All",
    "Favorites" : "Favorites",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Continue to %s" : " %sni davom eting",
    "Actions" : "Faolliklar"
},
"nplurals=1; plural=0;");
